@@ -7,7 +7,7 @@ class DBConnection:
     cursor = None
     def __init__(self, dbname, config):
         self.dbname = dbname
-        self.__config == config
+        self.__config = config
 
     def connect(self):
         config = self.__config
